@@ -70,20 +70,13 @@ pub enum Views {
 /// Gets a problem from passed in filepath and name of problem
 
 pub fn fetch_problem(problem_name: &str, problem_dir: &Path) -> MapmResult<Problem> {
-    match fs::read_to_string(problem_dir.join(&[problem_name, ".yml"].concat())) {
+    let problem_src = &problem_dir.join(&[problem_name, ".yml"].concat());
+    match fs::read_to_string(problem_src) {
         Ok(problem_yaml) => parse_problem_yaml(&problem_yaml),
-        Err(_) => Fail(ProblemErr(
-            [
-                "Could not read problem ",
-                &problem_name,
-                " from `",
-                &problem_dir.to_str().unwrap(),
-                "/",
-                &problem_name,
-                ".yml`",
-            ]
-            .concat(),
-        )),
+        Err(_) => Fail(ProblemErr(format!(
+            "Could not read problem `{}` from {:?}",
+            problem_name, problem_src
+        ))),
     }
 }
 
